@@ -1,47 +1,15 @@
 package MooseX::Fastly::Role;
-$MooseX::Fastly::Role::VERSION = '0.02';
+$MooseX::Fastly::Role::VERSION = '0.03';
 use Moose::Role;
+use Net::Fastly 1.08;
 use Carp;
 use HTTP::Tiny;
 
 requires 'config';    # Where we can read our config from?!?
 
-sub _cdn_service_ids {
-    my $self = $_[0];
-    my @service_ids;
-
-    my $service_ids = $self->config->{fastly_service_id};
-
-    return \@service_ids unless $service_ids;
-
-    @service_ids
-        = ref($service_ids) eq 'ARRAY' ? @{$service_ids} : ($service_ids);
-    return \@service_ids;
-}
-
-has '_fastly_http_client' => (
-    is         => 'ro',
-    lazy_build => '_build__fastly_http_client',
-);
-
-sub _build__fastly_http_client {
-    my $self = $_[0];
-
-    my $token = $self->config->{fastly_api_key};
-    return unless $token;
-
-    my $http_requester = HTTP::Tiny->new(
-        default_headers => {
-            'Fastly-Key' => $token,
-            'Accept'     => 'application/json'
-        },
-    );
-    return $http_requester;
-}
-
 =head1 NAME
 
-MooseX::Fastly::Role - Instantiate Net::Fastly api from config and purge methods
+MooseX::Fastly::Role - Fastly api from config, and purge methods
 
 =head1 SYSOPSIS
 
@@ -70,11 +38,16 @@ MooseX::Fastly::Role - Instantiate Net::Fastly api from config and purge methods
 
   $self->cdn_purge_all();
 
+  my $fastly = $self->cdn_api();
+  my $services = $self->cdn_services();
+
 =head1 DESCRIPTION
 
 L<Fastly|https://www.fastly.com/> is a global CDN (Content Delivery Network),
 used by many companies. This module requires a C<config> method to return
-a hashref.
+a hashref. This packages uses L<HTTP::Tiny> for most calls (so that you can
+use Fastly's token authentication for purging keys), but also provides
+accessors to L<Net::Fastly> for convenience.
 
 =head1 METHODS
 
@@ -92,19 +65,19 @@ Purge is called on all services, for each key.
 sub cdn_purge_now {
     my ( $self, $args ) = @_;
 
-    my $services = $self->_cdn_service_ids();
+    my $services = $self->_cdn_service_ids_from_config();
 
     foreach my $service_id ( @{$services} ) {
         foreach my $key ( @{ $args->{keys} || [] } ) {
             my $url = "/service/${service_id}/purge/${key}";
-            $self->_call_fastly( $url, $args->{soft_purge} );
+            $self->_call_fastly_http_client( $url, $args->{soft_purge} );
         }
     }
 
     return 1;
 }
 
-sub _call_fastly {
+sub _call_fastly_http_client {
     my ( $self, $url, $soft_purge ) = @_;
     $soft_purge ||= '0';
 
@@ -147,33 +120,113 @@ sub cdn_purge_all {
     foreach my $service_id ( @{$services} ) {
         foreach my $key ( @{ $args->{keys} || [] } ) {
             my $url = "/service/${service_id}/purge_all";
-            $self->_call_fastly( $url, $args->{soft_purge} );
+            $self->_call_fastly_http_client( $url, $args->{soft_purge} );
         }
     }
 
     return 1;
 }
 
+
+sub _cdn_service_ids_from_config {
+    my $self = $_[0];
+    my @service_ids;
+
+    my $service_ids = $self->config->{fastly_service_id};
+
+    return \@service_ids unless $service_ids;
+
+    @service_ids
+        = ref($service_ids) eq 'ARRAY' ? @{$service_ids} : ($service_ids);
+    return \@service_ids;
+}
+
+has '_fastly_http_client' => (
+    is         => 'ro',
+    lazy_build => '_build__fastly_http_client',
+);
+
+sub _build__fastly_http_client {
+    my $self = $_[0];
+
+    my $token = $self->config->{fastly_api_key};
+    return unless $token;
+
+    my $http_requester = HTTP::Tiny->new(
+        default_headers => {
+            'Fastly-Key' => $token,
+            'Accept'     => 'application/json'
+        },
+    );
+    return $http_requester;
+}
+
+
+=head1 Net::Fastly
+
+Methods below return objects from Net::Fastly.
+
 =head2 cdn_api
 
-This no longer works, heavily depreciated!
+  my $cdn_api = $self->cdn_api();
+
+If there is a B<fastly_api_key> in C<config> a C<Net::Fastly> instance is
+created and returned. Otherwise undef is returned (so you can develope
+safely if you do not set B<fastly_api_key> in the C<config>).
 
 =cut
 
-sub cdn_api {
-    warn "cdn_api - Not implimented any more, use Net::Fastly directly";
-    return 0;
+has 'cdn_api' => (
+    is         => 'ro',
+    lazy_build => '_build_cdn_api',
+);
+
+sub _build_cdn_api {
+    my $self = $_[0];
+
+    my $api_key = $self->config->{fastly_api_key};
+    return undef unless $api_key;
+
+    # We have the credentials, so must be on production
+    my $fastly = Net::Fastly->new( api_key => $api_key );
+    return $fastly;
 }
 
+
 =head2 cdn_services
 
-This no longer works, heavily depreciated!
+   my $services = $self->cdn_services();
+
+An array reference of C<Net::Fastly::Service> objects, based on the
+C<fastly_service_id> id(s) set in C<config>.
+
+The array reference will be empty if C<fastly_service_id> is not found
+in C<config>.
 
 =cut
 
-sub cdn_services {
-    warn "cdn_services does not work any more";
-    return 0;
+has 'cdn_services' => (
+    is         => 'ro',
+    lazy_build => '_build_cdn_services',
+);
+
+sub _build_cdn_services {
+    my ( $self, $args ) = @_;
+
+    my @services;
+
+    my $service_ids = $self->config->{fastly_service_id};
+    return \@services unless $service_ids;
+
+    my $cdn_api = $self->cdn_api();
+    return \@services unless $cdn_api;
+
+    my @service_ids
+        = ref($service_ids) eq 'ARRAY' ? @{$service_ids} : ($service_ids);
+
+    @services = map { $cdn_api->get_service($service_ids) } @service_ids;
+
+    return \@services;
 }
 
 =head1 AUTHOR
